@@ -21,10 +21,9 @@ mkdir -p "$(dirname "$EET_FILE")"
 
 # generate desc on a temporary file
 TMP_DESC=$(mktemp "$NAME-DESC-XXXXXX")
-TMP_EET=$(mktemp "$NAME-EET-XXXXXX")
 
 # trap to avoid creating orphan files
-trap 'rm -f "$TMP_DESC" "$TMP_EET"' INT TERM HUP EXIT
+trap 'rm -f "$TMP_DESC"' INT TERM HUP EXIT
 
 NAME=$($GET_NAME "$INI")
 
@@ -37,5 +36,5 @@ $EET -e "$EET_FILE" "$NAME" "$TMP_DESC" "$COMPRESS"
 
 rm "$TMP_DESC"
 
-# file successfully written, so need to trap to rename temp file
+# file successfully written, so no need to trap to remove temp file
 trap - INT TERM HUP EXIT
