@@ -21,7 +21,7 @@ static Color_Scheme default_colorscheme =
    .bg = CS(32, 32, 32), /* #202020 */
    .main = CS(53, 153, 255), /* #3599ff */
    .hl = CS(255,255,255), /* #ffffff */
-   .end_sel = CS(255,51,0), /* #ff3300 */
+   .end_sel = CS(53, 153, 255), /* #3599ff */
    .tab_missed_1 = CS(255,153,51), /* #ff9933 */
    .tab_missed_2 = CS(255,51,0), /* #ff3300 */
    .tab_missed_3 = CS(255,0,0), /* #ff0000 */
@@ -460,18 +460,18 @@ colors_term_init(Evas_Object *textgrid,
    if (!cs)
      cs = &default_colorscheme;
 
-#define CS_SET_INVISIBLE(_c)  do {                         \
+#define CS_SET_INVISIBLE(c_)  do {                         \
         evas_object_textgrid_palette_set(                  \
-           textgrid, EVAS_TEXTGRID_PALETTE_STANDARD, _c,   \
+           textgrid, EVAS_TEXTGRID_PALETTE_STANDARD, c_,   \
            0, 0, 0, 0);                                    \
 } while(0)
-#define CS_SET(_c, _F) do {                                \
-        r = cs->_F.r;                                      \
-        g = cs->_F.g;                                      \
-        b = cs->_F.b;                                      \
-        a = cs->_F.a;                                      \
+#define CS_SET(c_, F_) do {                                \
+        r = cs->F_.r;                                      \
+        g = cs->F_.g;                                      \
+        b = cs->F_.b;                                      \
+        a = cs->F_.a;                                      \
         evas_object_textgrid_palette_set(                  \
-           textgrid, EVAS_TEXTGRID_PALETTE_STANDARD, _c,   \
+           textgrid, EVAS_TEXTGRID_PALETTE_STANDARD, c_,   \
            r, g, b, a);                                    \
 } while (0)
 
@@ -532,13 +532,13 @@ colors_term_init(Evas_Object *textgrid,
    CS_SET(47 /* inverse bg */, faint.inverse_bg);
 #undef CS_SET
 
-#define CS_SET(_c, _F) do {                                \
-        r = cs->_F.r;                                      \
-        g = cs->_F.g;                                      \
-        b = cs->_F.b;                                      \
-        a = cs->_F.a;                                      \
+#define CS_SET(c_, F_) do {                                \
+        r = cs->F_.r;                                      \
+        g = cs->F_.g;                                      \
+        b = cs->F_.b;                                      \
+        a = cs->F_.a;                                      \
         evas_object_textgrid_palette_set(                  \
-           textgrid, EVAS_TEXTGRID_PALETTE_EXTENDED, _c,   \
+           textgrid, EVAS_TEXTGRID_PALETTE_EXTENDED, c_,   \
            r, g, b, a);                                    \
    } while (0)
 
@@ -608,24 +608,24 @@ color_scheme_apply(Evas_Object *edje,
 {
    EINA_SAFETY_ON_NULL_RETURN(cs);
 
-#define CS_SET(_K, _F) do {\
-   if (edje_object_color_class_set(edje, _K,                            \
-                               cs->_F.r, cs->_F.g, cs->_F.b, cs->_F.a,  \
-                               cs->_F.r, cs->_F.g, cs->_F.b, cs->_F.a,  \
-                               cs->_F.r, cs->_F.g, cs->_F.b, cs->_F.a)  \
+#define CS_SET(K_, F_) do {\
+   if (edje_object_color_class_set(edje, K_,                            \
+                               cs->F_.r, cs->F_.g, cs->F_.b, cs->F_.a,  \
+                               cs->F_.r, cs->F_.g, cs->F_.b, cs->F_.a,  \
+                               cs->F_.r, cs->F_.g, cs->F_.b, cs->F_.a)  \
        != EINA_TRUE)                                                    \
        {                                                                \
-          ERR("error setting color class '%s' on object %p", _K, edje); \
+          ERR("error setting color class '%s' on object %p", K_, edje); \
        }                                                                \
 } while (0)
-#define CS_SET_MANY(_K, _F1, _F2, _F3) do {                                \
-   if (edje_object_color_class_set(edje, _K,                               \
-                               cs->_F1.r, cs->_F1.g, cs->_F1.b, cs->_F1.a, \
-                               cs->_F2.r, cs->_F2.g, cs->_F2.b, cs->_F2.a, \
-                               cs->_F3.r, cs->_F3.g, cs->_F3.b, cs->_F3.a) \
+#define CS_SET_MANY(K_, F1_, F2_, F3_) do {                                \
+   if (edje_object_color_class_set(edje, K_,                               \
+                               cs->F1_.r, cs->F1_.g, cs->F1_.b, cs->F1_.a, \
+                               cs->F2_.r, cs->F2_.g, cs->F2_.b, cs->F2_.a, \
+                               cs->F3_.r, cs->F3_.g, cs->F3_.b, cs->F3_.a) \
        != EINA_TRUE)                                                       \
        {                                                                   \
-          ERR("error setting color class '%s' on object %p", _K, edje);    \
+          ERR("error setting color class '%s' on object %p", K_, edje);    \
        }                                                                   \
 } while (0)
 
@@ -638,13 +638,23 @@ color_scheme_apply(Evas_Object *edje,
    CS_SET_MANY("GLOW_TXT_HIGHLIGHT", hl, main, main);
 
    CS_SET("END_SELECTION", end_sel);
+   CS_SET("/fg/normal/term/selection/arrow/left", end_sel);
+   CS_SET("/fg/normal/term/selection/arrow/down", end_sel);
+   CS_SET("/fg/normal/term/selection/arrow/up", end_sel);
+   CS_SET("/fg/normal/term/selection/arrow/right", end_sel);
+
    CS_SET_MANY("TAB_MISSED", tab_missed_1, tab_missed_2, tab_missed_3);
    CS_SET_MANY("TAB_MISSED_OVER",
                tab_missed_over_1, tab_missed_over_2, tab_missed_over_3);
    CS_SET_MANY("TAB_TITLE", normal.def, tab_title_2, bg);
 
 #define CS_DARK      64,  64,  64, 255
-edje_object_color_class_set(edje, "BG_SENDFILE", CS_DARK, CS_DARK, CS_DARK);
+   if (edje_object_color_class_set(edje, "BG_SENDFILE", CS_DARK, CS_DARK, CS_DARK)
+       != EINA_TRUE)
+     {
+        ERR("error setting color class '%s' on object %p",
+              "BG_SENDFILE", edje);
+     }
 #undef CS_DARK
 
 #undef CS_SET
@@ -745,10 +755,11 @@ color_scheme_list(void)
    Eet_Entry *entry;
    Color_Scheme *cs;
    const char *current_name;
+   Eina_Bool default_found = EINA_FALSE;
 
    /* Search homedir first, so color classes there get used */
    snprintf(buf, sizeof(buf) - 1,
-            "%s/terminology/colorchemes",
+            "%s/terminology/colorschemes",
             efreet_config_home_get());
    search_paths = eina_list_append(search_paths, eina_stringshare_add(buf));
    snprintf(buf, sizeof(buf) - 1,
@@ -763,8 +774,6 @@ color_scheme_list(void)
      return NULL;
    memcpy(cs, &default_colorscheme, sizeof(*cs));
    l = eina_list_sorted_insert(l, color_scheme_cmp, cs);
-   /* Make sure default theme is the only theme */
-   name_list = eina_list_append(name_list, eina_stringshare_add("Default"));
 
    EINA_LIST_FREE(search_paths, sp)
       {
@@ -797,7 +806,7 @@ color_scheme_list(void)
                                  {
                                     WRN("Skipping loading '%s' from '%s' color scheme exists already",
                                        entry->name, buf);
-                                    eina_stringshare_del(entry->name);
+                                    eina_stringshare_del(current_name);
                                     continue;
                                  }
                               cs = eet_data_read(ef, edd_cs, entry->name);
@@ -805,11 +814,13 @@ color_scheme_list(void)
                                 {
                                    ERR("failed to load color scheme '%s' from '%s'",
                                        entry->name, buf);
-                                   eina_stringshare_del(entry->name);
+                                   eina_stringshare_del(current_name);
                                    continue;
                                 }
                               l = eina_list_sorted_insert(l, color_scheme_cmp, cs);
                               name_list = eina_list_append(name_list, current_name);
+                              if (strcmp(current_name, "Default") == 0)
+                                default_found = EINA_TRUE;
                            }
                         eet_close(ef);
                      }
@@ -817,6 +828,9 @@ color_scheme_list(void)
               free(file);
            }
      }
+   /* Make sure default theme is there */
+   if (!default_found)
+     name_list = eina_list_prepend(name_list, eina_stringshare_add("Default"));
 
    eina_iterator_free(it);
 
