@@ -140,14 +140,14 @@ sizeprint(char *sz, char szch)
    colorprint(RESET, 0, 0, 0, 0);
 }
 
-typedef struct _Cmatch
+typedef struct tag_Cmatch
 {
    short fr, fg, fb;
    short br, bg, bb;
    const char *match, *icon;
 } Cmatch;
 
-typedef struct _Tyls_Options
+typedef struct tag_Tyls_Options
 {
   int mode;
   Eina_Bool hidden;
@@ -313,6 +313,8 @@ const Cmatch fmatch[] =
    { 2, 3, 5,  9, 9, 9, "*.WAV", "audio-x-wav"},
    { 2, 3, 5,  9, 9, 9, "*.m3u", "audio-x-mp3-playlist"},
    { 2, 3, 5,  9, 9, 9, "*.M3U", "audio-x-mp3-playlist"},
+   { 2, 3, 5,  9, 9, 9, "*.pls", "audio-x-mp3-playlist"},
+   { 2, 3, 5,  9, 9, 9, "*.PLS", "audio-x-mp3-playlist"},
 
    { 3, 5, 2,  9, 9, 9, "*.patch", "text-x-generic"},
    { 3, 5, 2,  9, 9, 9, "*.PATCH", "text-x-generic"},
@@ -640,7 +642,7 @@ list_dir(const char *dir, Tyls_Options *options)
                {
                   for (c = 0; c < cols; c++)
                     {
-                       char sz[6], szch = ' ';
+                       char sz[32], szch = ' ';
                        long long size;
 
                        s = names[(c * rows) + i];
@@ -694,7 +696,7 @@ list_dir(const char *dir, Tyls_Options *options)
                   printf("\n");
                   for (c = 0; c < cols; c++)
                     {
-                       char sz[6], szch = ' ';
+                       char sz[32], szch = ' ';
                        long long size;
                        int len;
 
@@ -790,7 +792,7 @@ flush_file(Tyls_Options *options)
                {
                   for (c = 0; c < cols; c++)
                     {
-                       char sz[6], szch = ' ';
+                       char sz[32], szch = ' ';
                        long long size;
 
                        s = names[(c * rows) + i];
@@ -848,7 +850,7 @@ flush_file(Tyls_Options *options)
                   printf("\n");
                   for (c = 0; c < cols; c++)
                     {
-                       char sz[6], szch = ' ';
+                       char sz[32], szch = ' ';
                        long long size;
                        int len;
 
